@@ -31,7 +31,8 @@
 #include "ext_max_record.h"
 #include <ext_cert_type.h>
 #include <ext_server_name.h>
-#include "gnutls_num.h"
+#include <ext_srp.h>
+#include <gnutls_num.h>
 
 /* Key Exchange Section */
 #define GNUTLS_EXTENSION_ENTRY(type, ext_func_recv, ext_func_send) \
@@ -51,6 +52,9 @@ gnutls_extension_entry _gnutls_extensions[MAX_EXT_SIZE] = {
     GNUTLS_EXTENSION_ENTRY(GNUTLS_EXTENSION_SERVER_NAME,
 			   _gnutls_server_name_recv_params,
 			   _gnutls_server_name_send_params),
+    GNUTLS_EXTENSION_ENTRY(GNUTLS_EXTENSION_SRP,
+			   _gnutls_srp_recv_params,
+			   _gnutls_srp_send_params),
     {0, 0, 0, 0}
 };
 
