@@ -47,13 +47,13 @@ gnutls_credentials_type_t gnutls_auth_client_get_type(gnutls_session_t session);
 /* DH */
 
 void gnutls_dh_set_prime_bits(gnutls_session_t session, int bits);
-int gnutls_dh_get_secret_bits(gnutls_session_t);
-int gnutls_dh_get_peers_public_bits(gnutls_session_t);
-int gnutls_dh_get_prime_bits(gnutls_session_t);
+int gnutls_dh_get_secret_bits(gnutls_session_t session);
+int gnutls_dh_get_peers_public_bits(gnutls_session_t session);
+int gnutls_dh_get_prime_bits(gnutls_session_t session);
 
-int gnutls_dh_get_group(gnutls_session_t, gnutls_datum_t * gen,
-    gnutls_datum_t * prime);
-int gnutls_dh_get_pubkey(gnutls_session_t, gnutls_datum_t * pub);
+int gnutls_dh_get_group(gnutls_session_t session, gnutls_datum_t * raw_gen,
+    gnutls_datum_t * raw_prime);
+int gnutls_dh_get_pubkey(gnutls_session_t session, gnutls_datum_t * raw_key);
 
 /* RSA */
 int gnutls_rsa_export_get_pubkey(gnutls_session_t session,
@@ -65,43 +65,37 @@ int gnutls_rsa_export_get_modulus_bits(gnutls_session_t session);
 /* These are set on the credentials structure.
  */
 void
-gnutls_certificate_client_set_retrieve_function( gnutls_certificate_credentials_t,
-    gnutls_certificate_client_retrieve_function *);
-void gnutls_certificate_server_set_retrieve_function(gnutls_certificate_credentials_t,
-    gnutls_certificate_server_retrieve_function *);
+gnutls_certificate_client_set_retrieve_function( gnutls_certificate_credentials_t cred,
+    gnutls_certificate_client_retrieve_function *func);
+void gnutls_certificate_server_set_retrieve_function(gnutls_certificate_credentials_t cred,
+    gnutls_certificate_server_retrieve_function *func);
 
-void gnutls_certificate_server_set_request(gnutls_session_t,
-    gnutls_certificate_request_t);
-
-/* X.509 certificate handling functions 
- */
-
-int gnutls_pkcs3_extract_dh_params(const gnutls_datum_t * params,
-    gnutls_x509_crt_fmt_t format,
-    gnutls_datum_t * prime, gnutls_datum_t * generator, int *prime_bits);
-int gnutls_pkcs3_export_dh_params(const gnutls_datum_t * prime,
-    const gnutls_datum_t * generator, gnutls_x509_crt_fmt_t format,
-    unsigned char *params_data, int *params_data_size);
+void gnutls_certificate_server_set_request(gnutls_session_t session,
+    gnutls_certificate_request_t req);
 
 /* get data from the session 
  */
-const gnutls_datum_t *gnutls_certificate_get_peers(gnutls_session_t,
+const gnutls_datum_t *gnutls_certificate_get_peers(gnutls_session_t session,
     unsigned int *list_size);
 const gnutls_datum_t *gnutls_certificate_get_ours(gnutls_session_t session);
 
 time_t gnutls_certificate_activation_time_peers(gnutls_session_t session);
 time_t gnutls_certificate_expiration_time_peers(gnutls_session_t session);
 
-int gnutls_certificate_client_get_request_status(gnutls_session_t);
-int gnutls_certificate_verify_peers2(gnutls_session_t, unsigned int* status);
+int gnutls_certificate_client_get_request_status(gnutls_session_t session);
+int gnutls_certificate_verify_peers2(gnutls_session_t session,
+				     unsigned int* status);
 
-int gnutls_pem_base64_encode(const char *header, const gnutls_datum_t * data,
+/* this is obsolete (?). */
+int gnutls_certificate_verify_peers(gnutls_session_t session);
+
+int gnutls_pem_base64_encode(const char *msg, const gnutls_datum_t * data,
     char *result, size_t * result_size);
 int gnutls_pem_base64_decode(const char *header,
     const gnutls_datum_t * b64_data,
     unsigned char *result, size_t * result_size);
 
-int gnutls_pem_base64_encode_alloc(const char *header,
+int gnutls_pem_base64_encode_alloc(const char *msg,
     const gnutls_datum_t * data, gnutls_datum_t * result);
 int gnutls_pem_base64_decode_alloc(const char *header,
     const gnutls_datum_t * b64_data, gnutls_datum_t * result);
@@ -134,9 +128,9 @@ typedef struct gnutls_params_st {
 typedef int gnutls_params_function(gnutls_session_t, gnutls_params_type_t,
 				   gnutls_params_st *);
 
-void gnutls_certificate_set_params_function(gnutls_certificate_credentials_t
-					    res,
-					    gnutls_params_function * func);
+void
+gnutls_certificate_set_params_function(gnutls_certificate_credentials_t res,
+				       gnutls_params_function * func);
 void gnutls_anon_set_params_function(gnutls_certificate_credentials_t res,
 				     gnutls_params_function * func);
 
