@@ -39,7 +39,6 @@
 /* Gnulib portability files. */
 #include <getline.h>
 #include <error.h>
-#include <exit.h>
 #include <progname.h>
 
 static void print_crl_info(gnutls_x509_crl crl, FILE * out, int all);
@@ -1677,7 +1676,7 @@ gnutls_x509_crt load_cert(int mand)
 
     crt = load_cert_list(mand, &size);
 
-    return crt[0];
+    return crt ? crt[0] : NULL;
 }
 
 #define MAX_CERTS 256
